<?php
/* gvHIDRA. Herramienta Integral de Desarrollo Rpido de Aplicaciones de la Generalitat Valenciana
*
* Copyright (C) 2006 Generalitat Valenciana.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
*
* For more information, contact:
*
*  Generalitat Valenciana
*  Conselleria d'Infraestructures i Transport
*  Av. Blasco Ibez, 50
*  46010 VALENCIA
*  SPAIN
*  +34 96386 24 83
*  gvhidra@gva.es
*  www.gvhidra.org
*
*/

/**
* Clase Manejadora Puerto
* 
* Creada con Genaro: generador de cdigo de gvHIDRA
* 
* @autor genaro
* @version 1.0
* @license http://opensource.org/licenses/gpl-2.0.php GNU Public License v.2
*/

class Puerto extends gvHidraForm_DB
{
	public function __construct() {

		//Recogemos dsn de conexion
		$conf = ConfigFramework::getConfig();
		$g_dsn = $conf->getDSN('g_dsn');

		$nombreTablas= array('puerto');
		parent::__construct($g_dsn, $nombreTablas);


		/************************ QUERYs ************************/
		
		//Consulta del modo de trabajo EDI
		$str_select = "SELECT cpuerto as \"cpuerto\", dpuerto as \"edi_dpuerto\", direccion as \"edi_direccion\", telefono as \"edi_telefono\", municipio_cmun as \"edi_municipio_cmun\", provincia_cprov as \"edi_provincia_cprov\" FROM puerto, municipio";
		$this->setSelectForSearchQuery($str_select);
		
		$str_where = "municipio.cmun = puerto.municipio_cmun";
		$this->setWhereForSearchQuery($str_where);

		//Where del modo de trabajo EDI
		//$str_where = "";
		//$this->setWhereForSearchQuery($str_where);

		//Order del modo de trabajo EDI
		$this->setOrderByForSearchQuery('1');

		/************************ END QUERYs ************************/
		


		/************************ MATCHINGs ************************/

		//Seccion de matching: asociacion campos TPL y campos BD

		//Modo de trabajo FIL		
		$this->addMatching("cpuerto","cpuerto","puerto");
		$this->addMatching("fil_dpuerto","dpuerto","puerto");
		$this->addMatching("fil_direccion","direccion","puerto");
		$this->addMatching("fil_telefono","telefono","puerto");
		$this->addMatching("fil_municipio_cmun","municipio_cmun","puerto");

		//Modo de trabajo EDI
		$this->addMatching("cpuerto","cpuerto","puerto");
		$this->addMatching("edi_dpuerto","dpuerto","puerto");
		$this->addMatching("edi_direccion","direccion","puerto");
		$this->addMatching("edi_telefono","telefono","puerto");
		$this->addMatching("edi_municipio_cmun","municipio_cmun","puerto");

		/************************ END MATCHINGs ************************/


		/************************ TYPEs ************************/

		//Fechas: gvHidraDate type
		$fecha = new gvHidraDate(false);
		$fecha->setCalendar(true);

		//Strings: gvHidraString type
		$string = new gvHidraString(false, 5);
		$this->addFieldType('fil_cpuerto',$string);
		$this->addFieldType('edi_cpuerto',$string);
		$string = new gvHidraString(false, 50);
		$this->addFieldType('fil_dpuerto',$string);
		$this->addFieldType('edi_dpuerto',$string);
		$string = new gvHidraString(false, 50);
		$this->addFieldType('fil_direccion',$string);
		$this->addFieldType('edi_direccion',$string);
		$string = new gvHidraString(false, 20);
		$this->addFieldType('fil_telefono',$string);
		$this->addFieldType('edi_telefono',$string);

		//Integers: gvHidraInteger type	

		//Floats: gvHidraFloat type

		/************************ END TYPEs ************************/
		
		/************************ COMPONENTS ************************/
		
		//Declaracion de Listas y WindowSelection
		$listaProvincias_fil = new gvHidraList('fil_cod_prov','PROVINCIAS');
		$listaProvincias_fil->addOption("","");
		$this->addList($listaProvincias_fil);
	
		$listaMunicipios_fil = new gvHidraList('fil_municipio_cmun','MUNICIPIOS');
		$listaMunicipios_fil->addOption("","");
		$listaMunicipios_fil->setDependence(array('fil_cod_prov'),array('municipio.provincia_cprov'));
		$this->addList($listaMunicipios_fil);
			
		$listaProvincias_edi = new gvHidraList('edi_cod_prov','PROVINCIAS');
		$listaProvincias_edi->addOption("","");
		$this->addList($listaProvincias_edi);
	
		$listaMunicipios_edi = new gvHidraList('edi_municipio_cmun','MUNICIPIOS');
		$listaMunicipios_edi->addOption("","");
		$listaMunicipios_edi->setDependence(array('edi_cod_prov'),array('municipio.provincia_cprov'));
		$this->addList($listaMunicipios_edi);
		//La definicin debe estar en el AppMainWindow.php
		
		
		/************************ END COMPONENTS ************************/						

		//Relacionamos con las clases detalle
		$this->addHijo('Estancia', array('cpuerto'), array('puerto_cpuerto'));

		//Mantener los valores del modo de trabajo FIL tras la busqueda
		$this->keepFilterValuesAfterSearch(true);

	}//End construct

	/************************ CRUD METHODs ************************/

	/**
	* metodo preBuscar
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui la logica para parametrizar la busqueda. Por ejemplo:
	* - Incluir condiciones de filtrado.
	* - Cancelar la accion de buscar. 
	*/	
	public function preBuscar($objDatos) {
		
		return 0;
	}

	/**
	* metodo postBuscar
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui la logica para parametrizar los datos obtenidos. Por ejemplo:
	* - Completar la informacion obtenida.
	* - Cambiar el color de las filas dependiendo de su valor
	*/	
	public function postBuscar($objDatos) {
		
		return 0;
	}

	/**
	* metodo preInsertar
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui la logica para parametrizar los datos a insertar. Por ejemplo:
	* - Calcular el valor de una secuencia.
	* - Cancelar la accin de insercion.
	*/		
	public function preInsertar($objDatos) {
		
		return 0;
	}
	
	/**
	* metodo postInsertar
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui la logica para completar la operacion de insercion. Por ejemplo:
	* - Insertar en una segunda tabla.
	*/		
	public function postInsertar($objDatos) {
		
		return 0;
	}

	/**
	* metodo preModificar
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui la logica para parametrizar la operacion de actualizacion. Por ejemplo:
	* - Calcular valores derivados.
	* - Cancelar la accin de actualizacion.
	*/
	public function preModificar($objDatos) {
		
		return 0;
	}
	
	/**
	* metodo postModificar
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui la logica para completar la operacion de actulizacion. Por ejemplo:
	* - Actualizar en una segunda tabla
	*/	
	public function postModificar($objDatos) {
		
		return 0;
	}
	
	/**
	* metodo preBorrar
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui la logica para parametrizar la operacion de borrado. Por ejemplo:
	* - Cancelar la accin de borrado.
	*/	
	public function preBorrar($objDatos) {
		
		return 0;
	}
	
	/**
	* metodo postBorrar
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui la logica para completar la operacion de borrado. Por ejemplo:
	* - Borrar en una segunda tabla
	*/	
	public function postBorrar($objDatos) {
		
		return 0;
	}
	
	/**
	* metodo preNuevo
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui los valores por defecto antes de insertar.
	*/	
	public function preNuevo($objDatos) {
		
		return 0;
	}
	
	/**
	* metodo preIniciarVentana
	* 
	* @access public
	* @param object $objDatos
	* 
	* Incorpore aqui la logica a ejecutar cuando entra en la ventana. Por ejemplo:
	* - Puede comprobar que el usuario tiene los permisos necesarios.
	*/	
	public function preIniciarVentana($objDatos) {
		
		return 0;
	}
	
	/************************ END CRUD METHODs ************************/
	
	/**
	* metodo accionesParticulares
	* 
	* @access public
	* @param string $str_accion
	* @param object $objDatos
	* 
	* Incorpore aqui la logica de sus acciones particulares. 
	* -En el parametro $str_accion aparece el id de la accion.
	* -En el parametro $objDatos esta la informacion de la peticion. Recuerde que debe fijar la operacion
	* con el metodo setOperacion.
	*/	
	public function accionesParticulares($str_accion, $objDatos) {
        
		throw new Exception('Se ha intentado ejecutar la accin '.$str_accion.' y no est programada.');        
    }
	
}//End 

?>